package com.sobuumedia.sobuu.android.coreUI.portrait.molecules

import android.content.res.Configuration
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.semantics.contentDescription
import androidx.compose.ui.semantics.semantics
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.sobuumedia.sobuu.SharedRes.strings.home_main_finishedBookOn
import com.sobuumedia.sobuu.SharedRes.strings.home_main_gaveUpBookOn
import com.sobuumedia.sobuu.SharedRes.strings.home_main_startedBookOn
import com.sobuumedia.sobuu.android.coreUI.portrait.atoms.BookThumbnail
import com.sobuumedia.sobuu.android.coreUI.portrait.atoms.CircularProgressIndicator
import com.sobuumedia.sobuu.android.main.toStringDateWithDayAndTime
import com.sobuumedia.sobuu.android.settings.theme.SobuuTheme
import com.sobuumedia.sobuu.android.settings.theme.Typography
import com.sobuumedia.sobuu.android.utils.stringResource
import kotlinx.datetime.Clock
import kotlinx.datetime.LocalDateTime
import kotlinx.datetime.TimeZone
import kotlinx.datetime.toLocalDateTime

// This is an alternative design for the BookCards in the home screen.
// I'm not 100% convinced about this design, but I want ot study it in the future again
@Composable
fun AlternativeBookCard(
    modifier: Modifier = Modifier,
    picture: String,
    progress: Double,
    startedToRead: LocalDateTime?,
    finishedToRead: LocalDateTime?,
    title: String,
    authors: String,
    finished: Boolean,
    giveUp: Boolean,
) {
    val context = LocalContext.current
    val textColor = MaterialTheme.colorScheme.background
    val transparent = Color.Transparent
    val backgroundColor = MaterialTheme.colorScheme.secondary
    val startedDateText = "${home_main_startedBookOn.stringResource(context = context)} ${
        startedToRead?.toStringDateWithDayAndTime() ?: Clock.System.now()
            .toLocalDateTime(TimeZone.UTC).toStringDateWithDayAndTime()
    }"
    val finishedDateText = if (finished || giveUp) {
        "${
            if (finished) {
                home_main_finishedBookOn.stringResource(context = context)
            } else {
                home_main_gaveUpBookOn.stringResource(context = context)
            }
        } ${
            finishedToRead?.toStringDateWithDayAndTime()
        }"
    } else {
        ""
    }

    Box(
        modifier = Modifier
            .clip(RoundedCornerShape(20.dp))
            .then(modifier)
    ) {
        Box(
            modifier = Modifier.fillMaxHeight()
                .clip(RoundedCornerShape(20.dp))
                .background(
                    brush = Brush.verticalGradient(
                        colors = listOf(
                            transparent,
                            backgroundColor
                        )
                    )
                )
        ) {
            BookThumbnail(imageURL = picture)

            Box(
                modifier = Modifier
                    .fillMaxWidth(0.9f)
                    .fillMaxHeight(0.1f),
                contentAlignment = Alignment.BottomEnd
            ) {
                CircularProgressIndicator(progress = progress)
            }

            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(10.dp),
                verticalArrangement = Arrangement.Bottom
            ) {

                Row {
                    Text(
                        text = startedDateText,
                        style = Typography.bodySmall.copy(color = textColor),
                        modifier = Modifier
                            .padding(horizontal = 10.dp)
                            .semantics { this.contentDescription = startedDateText }
                    )

                    if (finishedToRead != null && (finished || giveUp)) {
                        Text("|", style = Typography.bodySmall.copy(color = textColor))
                        Text(finishedDateText,
                            style = Typography.bodySmall.copy(color = textColor),
                            modifier = Modifier
                                .padding(horizontal = 10.dp)
                                .semantics { this.contentDescription = finishedDateText }
                        )
                    }
                }

                Column(
                    modifier = Modifier.fillMaxWidth()
                ) {
                    Text(
                        text = title,
                        style = Typography.bodyLarge.copy(color = textColor, fontWeight = FontWeight.Medium),
                        textAlign = TextAlign.Start,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(10.dp)
                            .semantics { this.contentDescription = title }
                    )

                    Text(
                        text = authors,
                        style = Typography.bodyMedium.copy(color = textColor),
                        textAlign = TextAlign.Start,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(start = 10.dp)
                            .semantics { this.contentDescription = authors }
                    )
                }
            }
        }
    }
}


@Preview(showSystemUi = false, showBackground = true, uiMode = Configuration.UI_MODE_NIGHT_NO)
@Composable
fun AlternativeBookCardPreview() {
    SobuuTheme {
        AlternativeBookCard(
            progress = 93.0,
            startedToRead = Clock.System.now().toLocalDateTime(TimeZone.UTC),
            finished = true,
            finishedToRead = Clock.System.now().toLocalDateTime(TimeZone.UTC),
            picture = "",
            giveUp = false,
            authors = listOf("Steph Ryan, Blake Sorgenson, Jeffrey O'Connell ").joinToString(", "),
            title = "Testing books with an extra large name and more than one author"
        )
    }
}